aboutsummaryrefslogtreecommitdiffstats
path: root/tools/pwg_rel_create.sh
diff options
context:
space:
mode:
Diffstat (limited to 'tools/pwg_rel_create.sh')
-rwxr-xr-xtools/pwg_rel_create.sh6
1 files changed, 3 insertions, 3 deletions
diff --git a/tools/pwg_rel_create.sh b/tools/pwg_rel_create.sh
index 0dadbe759..424b703d9 100755
--- a/tools/pwg_rel_create.sh
+++ b/tools/pwg_rel_create.sh
@@ -34,9 +34,9 @@ mkdir $version
# cvs export -r $tag -d $version phpwebgallery
svn export http://piwigo.org/svn/tags/$tag $name
-# creating mysql.inc.php empty and writeable
-touch $name/include/mysql.inc.php
-chmod a+w $name/include/mysql.inc.php
+# creating config_database.inc.php empty and writeable
+touch $name/include/config_database.inc.php
+chmod a+w $name/include/config_database.inc.php
# find $name -name "*.php" \
# | xargs grep -l 'branch 1.7' \